//*****************************************************************************
//*
//*
//*		KreditCalculatorDlg.cpp : Implementierungsdatei
//*
//*
//*****************************************************************************
//
//	(C) Copyright Anton Zechner 2007
//
#include "StdAfx.h"
#include "KreditCalculator.h"
#include "KreditCalculatorDlg.h"
#include "AfxUtility.h"

#ifdef		_DEBUG
#define new	 DEBUG_NEW
#undef		 THIS_FILE
char  THIS_FILE[] = __FILE__;
#endif


BEGIN_MESSAGE_MAP(CKreditCalculatorDlg, CDialog)
	//{{AFX_MSG_MAP(CKreditCalculatorDlg)
	ON_WM_SYSCOMMAND()
	ON_WM_PAINT()
	ON_WM_QUERYDRAGICON()
	ON_BN_CLICKED(IDC_CHECK1, OnCheck1)
	ON_BN_CLICKED(IDC_CHECK2, OnCheck2)
	ON_BN_CLICKED(IDC_CHECK3, OnCheck3)
	ON_BN_CLICKED(IDC_CHECK4, OnCheck4)
	ON_BN_CLICKED(IDC_CHECK5, OnCheck6)
	ON_EN_CHANGE(IDC_EDIT1, OnChangeEdit1)
	ON_EN_CHANGE(IDC_EDIT2, OnChangeEdit2)
	ON_EN_CHANGE(IDC_EDIT3, OnChangeEdit3)
	ON_EN_CHANGE(IDC_EDIT4, OnChangeEdit4)
	ON_EN_CHANGE(IDC_EDIT5, OnChangeEdit5)
	ON_EN_CHANGE(IDC_EDIT6, OnChangeEdit6)
	ON_EN_KILLFOCUS(IDC_EDIT1, OnKillfocusEdit1)
	ON_EN_KILLFOCUS(IDC_EDIT2, OnKillfocusEdit2)
	ON_EN_KILLFOCUS(IDC_EDIT3, OnKillfocusEdit3)
	ON_EN_KILLFOCUS(IDC_EDIT4, OnKillfocusEdit4)
	ON_EN_KILLFOCUS(IDC_EDIT5, OnKillfocusEdit5)
	ON_EN_KILLFOCUS(IDC_EDIT6, OnKillfocusEdit6)
	ON_NOTIFY(TCN_SELCHANGE, IDC_TAB1, OnSelchangeTab)
	ON_WM_CTLCOLOR()
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

#define 	COLOR_DIS	RGB(220,220,255)
#define 	COLOR_OUT	RGB(255,220,220)
#define 	COLOR_DEF	RGB(255,255,200)

HBRUSH		hBrushDis;
HBRUSH		hBrushOut;
HBRUSH		hBrushDef;


//*****************************************************************************
//*
//*		KreditRate
//*
//*****************************************************************************
//	Berechnet die Hhe der Monatsraten
//	dSumme		: Kretitsumme
//	dZinsen		: Zinssatz in % jhrlich
//	dLaufzeit	: Laufzeit in Monaten
//	dSpesen		: Spesen die zur Kreditsumme hinzukommen
double KreditRate(double dSumme,double dZinsen,double dLaufzeit,double dSpesen)
{
double	z_pow_n,rate;


	if(dZinsen  <0.0)dZinsen  =0.0;
	if(dLaufzeit<1.0)dLaufzeit=1.0;

	dZinsen/=1200.0;
	dZinsen+=1.0;


	z_pow_n = pow(dZinsen,dLaufzeit);
	if(z_pow_n<1.00000001)z_pow_n=1.00000001;

	rate=(dSumme+dSpesen)*(dZinsen-1.0)/(z_pow_n-1.0)*z_pow_n;


return rate;
}

//*****************************************************************************
//*
//*		KreditSpesen
//*
//*****************************************************************************
//	Berechnet die Hhe der Kreditpesen
//	dSumme		: Spesen die zur Kreditsumme hinzukommen
//	dRate		: Monatliche Rckzahlungsrate
//	dZinsen		: Zinssatz in % jhrlich
//	dLaufzeit	: Laufzeit in Monaten
double KreditSpesen(double dSumme,double dRate,double dZinsen,double dLaufzeit)
{
double	z_pow_n,spesen;


	if(dZinsen  <0.0)dZinsen  =0.0;
	if(dLaufzeit<1.0)dLaufzeit=1.0;

	dZinsen/=1200.0;
	dZinsen+=1.0;

	if(dZinsen<1.000001)dZinsen=1.000001;

	z_pow_n = pow(dZinsen,dLaufzeit);

	spesen  = dRate*(z_pow_n-1.0)/(dZinsen-1.0)/z_pow_n;
	spesen -= dSumme;


return spesen;
}
//*****************************************************************************
//*
//*		KreditSumme
//*
//*****************************************************************************
//	Berechnet die Hhe der Kreditsumme
//	dRate		: Monatliche Rckzahlungsrate
//	dZinsen		: Zinssatz in % jhrlich
//	dLaufzeit	: Laufzeit in Monaten
//	dSpesen		: Spesen die zur Kreditsumme hinzukommen
double KreditSumme(double dRate,double dZinsen,double dLaufzeit,double dSpesen)
{
double	z_pow_n,summe;


	if(dZinsen  <0.0)dZinsen  =0.0;
	if(dLaufzeit<1.0)dLaufzeit=1.0;

	dZinsen/=1200.0;
	dZinsen+=1.0;

	if(dZinsen<1.000001)dZinsen=1.000001;

	z_pow_n = pow(dZinsen,dLaufzeit);

	summe  = dRate*(z_pow_n-1.0)/(dZinsen-1.0)/z_pow_n;
	summe -= dSpesen;


return summe;
}

//*****************************************************************************
//*
//*		KreditLaufzeit
//*
//*****************************************************************************
//	Berechnet die Anzahl der zu zahlenden Monatsraten
//	dSumme		: Kretitsumme
//	dZinsen		: Zinssatz in % jhrlich
//	dRate		: Monatliche Rckzahlungsrate
//	dSpesen		: Spesen die zur Kreditsumme hinzukommen
double KreditLaufzeit(double dSumme,double dZinsen,double dRate,double dSpesen)
{
double	y,laufzeit;


	if(dZinsen<0.0)dZinsen=0.0;

	dZinsen/=1200.0;
	dZinsen+=1.0;


	if(dZinsen<1.000001)dZinsen=1.000001;

	y = 1.0 - (dSumme+dSpesen)/dRate*(dZinsen-1.0);
	if(y<0.000001)y=0.000001;

	laufzeit=log(1.0/y)/log(dZinsen);


return laufzeit;
}

//*****************************************************************************
//*
//*		KreditZinsen
//*
//*****************************************************************************
//	Berechnet die Hhe der jhrlichen Zinsen in %
//	dSumme		: Kretitsumme
//	dLaufzeit	: Laufzeit in Monaten
//	dRate		: Monatliche Rckzahlungsrate
//	dSpesen		: Spesen die zur Kreditsumme hinzukommen
double KreditZinsen(double dSumme,double dLaufzeit,double dRate,double dSpesen)
{
double	y,delta,step,wert,z_pow_n,zinsen;
int		i=0;


	if(dRate<0.00001)dRate=0.00001;
	if(dLaufzeit<1.0)dLaufzeit=1.0;

	wert=(dSumme+dSpesen)/dRate;
	zinsen=1.04;
	step=0.04;
	i=0;

	while(step>0.0002)
		{
		i++;
		if(i>2000)break;

		z_pow_n = pow(zinsen,dLaufzeit);
		y=(z_pow_n-1.0)/(zinsen-1.0)/z_pow_n;
		delta=y-wert;

		if(delta>0.0)
			{
			zinsen+=step;
			}
		else{
			step/=2.0;
			zinsen-=step;
			}
		}


return (zinsen-1.0)*1200.0;
}

//*****************************************************************************
//*
//*		SparenRate
//*
//*****************************************************************************
//	Berechnet die Hhe der Monatsraten
//	dSumme		: Ist die anfangs eingezahlte Summe
//	dZinsen		: Zinssatz in % jhrlich
//	dLaufzeit	: Laufzeit in Monaten
//	dSparziel	: Ist die Summe die angespart werden soll
double SparRate(double dSumme,double dZinsen,double dLaufzeit,double dSparziel)
{
double	z_pow_n,rate;


	if(dZinsen  <0.0)dZinsen  =0.0;
	if(dLaufzeit<1.0)dLaufzeit=1.0;

	dZinsen/=1200.0;
	dZinsen+=1.0;

	if(dZinsen<1.000001)
		{
		rate=(dSparziel-dSumme)/dLaufzeit;
		}
	else{
		z_pow_n = pow(dZinsen,dLaufzeit);
		rate=(dSparziel-dSumme*z_pow_n)/(z_pow_n-1.0)*(dZinsen-1.0);
		}


return rate;
}

//*****************************************************************************
//*
//*		SparSumme
//*
//*****************************************************************************
//	Berechnet die Hhe der vorab eingezahlten Summe
//	dRate		: Monatliche Einzahlungsrate
//	dZinsen		: Zinssatz in % jhrlich
//	dLaufzeit	: Laufzeit in Monaten
//	dSparziel	: Ist die Summe die angespart werden soll
double SparSumme(double dRate,double dZinsen,double dLaufzeit,double dSparziel)
{
double	z_pow_n,summe;


	if(dZinsen  <0.0)dZinsen  =0.0;
	if(dLaufzeit<1.0)dLaufzeit=1.0;

	dZinsen/=1200.0;
	dZinsen+=1.0;

	if(dZinsen<1.000001)dZinsen=1.000001;

	z_pow_n = pow(dZinsen,dLaufzeit);

	summe=(dSparziel-dRate*(z_pow_n-1.0)/(dZinsen-1.0))/z_pow_n;


return summe;
}

//*****************************************************************************
//*
//*		SparLaufzeit
//*
//*****************************************************************************
//	Berechnet die Anzahl der zu zahlenden Monatsraten
//	dSumme		: Ist die anfangs eingezahlte Summe
//	dZinsen		: Zinssatz in % jhrlich
//	dRate		: Monatliche Einzahlungsrate
//	dSparziel	: Ist die Summe die angespart werden soll
double SparLaufzeit(double dSumme,double dZinsen,double dRate,double dSparziel)
{
double	y,laufzeit;


	if(dZinsen<0.0)dZinsen=0.0;

	dZinsen/=1200.0;
	dZinsen+=1.0;


	if(dZinsen<1.000001)
		{
		if(dRate<0.0001)dRate=0.0001;
		laufzeit=(dSparziel-dSumme)/dRate;
		return laufzeit;
		}

	y = (dSparziel+dRate/(dZinsen-1.0))/(dSumme+dRate/(dZinsen-1.0));
	if(y<0.000001)y=0.000001;
	laufzeit=log(y)/log(dZinsen);


return laufzeit;
}

//*****************************************************************************
//*
//*		SparSparziel
//*
//*****************************************************************************
//	Berechnet die Summe die angespart wird
//	dSumme		: Ist die anfangs eingezahlte Summe
//	dZinsen		: Zinssatz in % jhrlich
//	dRate		: Monatliche Einzahlungsrate
//	dLaufzeit	: Laufzeit in Monaten
double SparSparziel(double dSumme,double dZinsen,double dRate,double dLaufzeit)
{
double	summe,z_pow_n;


	if(dZinsen<0.0)dZinsen=0.0;

	dZinsen/=1200.0;
	dZinsen+=1.0;

	if(dZinsen<1.000001)
		{
		summe = dSumme + dRate*dLaufzeit;
		}
	else{
		z_pow_n = pow(dZinsen,dLaufzeit);
		summe = dSumme*z_pow_n + dRate*(z_pow_n-1.0)/(dZinsen-1.0);
		}


return summe;
}

//*****************************************************************************
//*
//*		SparZinsen
//*
//*****************************************************************************
//	Berechnet die Hhe der jhrlichen Zinsen in %
//	dSumme		: Ist die anfangs eingezahlte Summe
//	dLaufzeit	: Laufzeit in Monaten
//	dRate		: Monatliche Einzahlungsrate
//	dSparziel	: Ist die Summe die angespart werden soll
double SparZinsen(double dSumme,double dLaufzeit,double dRate,double dSparziel)
{
double	y,delta,step,z_pow_n,zinsen;
int		i;

	if(dRate<0.00001)dRate=0.00001;
	if(dLaufzeit<1.0)dLaufzeit=1.0;

	zinsen=1.04;
	step=0.04;
	i=0;

	while(step>0.0002)
		{
		i++;
		if(i>2000)break;
		z_pow_n = pow(zinsen,dLaufzeit);
		y =dSumme*z_pow_n+dRate*(z_pow_n-1.0)/(zinsen-1.0);
		delta=y-dSparziel;

		if(delta<0.0)
			{
			zinsen+=step;
			}
		else{
			step/=2.0;
			zinsen-=step;
			}
		}


return (zinsen-1.0)*1200.0;
}

//*****************************************************************************
//*
//*		CKreditCalculatorDlg Dialogfeld
//*
//*****************************************************************************
CKreditCalculatorDlg::CKreditCalculatorDlg(CWnd *pParent)
	: CDialog(CKreditCalculatorDlg::IDD,pParent)
{
	//{{AFX_DATA_INIT(CKreditCalculatorDlg)
	//}}AFX_DATA_INIT
	m_hIcon		= AfxGetApp()->LoadIcon(IDR_MAINFRAME);

	dSumme		= 0.0;
	dZinsen		= 7.0;
	dRate		= 0.0;
	dLaufzeit	= 0.0;
	dJahre		= 0.0;
	dZahlung	= 0.0;
	dSparziel	= 0.0;
	dZinszahlung= 0.0;
	iFixNr		= 4;
	iTypNr		= 0;
}

//*****************************************************************************
//*
//*		DoDataExchange
//*
//*****************************************************************************
void CKreditCalculatorDlg::DoDataExchange(CDataExchange *pDX)
{
int		 iId;
CWnd	*pWnd;

	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CKreditCalculatorDlg)
	DDX_Control(pDX, IDC_TAB1, m_cTabCtrl);
	//}}AFX_DATA_MAP

	pWnd= GetFocus();
	iId = (pWnd)? GetWndId(pWnd):0;

	if(iId!=IDC_EDIT1 || pDX->m_bSaveAndValidate)DDX_Float ( pDX , IDC_EDIT1 , dSumme		, 2);
	if(iId!=IDC_EDIT2 || pDX->m_bSaveAndValidate)DDX_Float ( pDX , IDC_EDIT2 , dZinsen		, 2);
	if(iId!=IDC_EDIT3 || pDX->m_bSaveAndValidate)DDX_Float ( pDX , IDC_EDIT3 , dRate		, 2);
	if(iId!=IDC_EDIT4 || pDX->m_bSaveAndValidate)DDX_Float ( pDX , IDC_EDIT4 , dLaufzeit	, 2);
	if(iId!=IDC_EDIT5 || pDX->m_bSaveAndValidate)DDX_Float ( pDX , IDC_EDIT5 , dJahre		, 2);
	if(iId!=IDC_EDIT6 || pDX->m_bSaveAndValidate)DDX_Float ( pDX , IDC_EDIT6 , dSparziel	, 2);
												 DDX_Float ( pDX , IDC_EDIT7 , dZahlung		, 2);
												 DDX_Float ( pDX , IDC_EDIT8 , dZinszahlung , 2);


	if(pDX->m_bSaveAndValidate)
		{
		if(iId!=IDC_EDIT5)dJahre=dLaufzeit/12.0;
		else			  dLaufzeit=dJahre*12.0;
		}


}



//*****************************************************************************
//*
//*		OnInitDialog
//*
//*****************************************************************************
BOOL CKreditCalculatorDlg::OnInitDialog()
{

	hBrushDis = CreateSolidBrush(COLOR_DIS);
	hBrushOut = CreateSolidBrush(COLOR_OUT);
	hBrushDef = CreateSolidBrush(COLOR_DEF);


	CDialog::OnInitDialog();

	ASSERT((IDM_ABOUTBOX & 0xFFF0) == IDM_ABOUTBOX);
	ASSERT( IDM_ABOUTBOX < 0xF000);

	CMenu* pSysMenu = GetSystemMenu(FALSE);
	if(pSysMenu != NULL)
		{
		CString strAboutMenu;
		strAboutMenu.LoadString(IDS_ABOUTBOX);
		if (!strAboutMenu.IsEmpty())
			{
			pSysMenu->AppendMenu(MF_SEPARATOR);
			pSysMenu->AppendMenu(MF_STRING, IDM_ABOUTBOX, strAboutMenu);
			}
		}

	SetIcon(m_hIcon, TRUE);			// Groes Symbol verwenden
	SetIcon(m_hIcon, FALSE);		// Kleines Symbol verwenden

	GetDlgButton(IDC_CHECK4)->SetCheck(1);
	GetDlgEdit  (IDC_EDIT4 )->SetReadOnly(1);
	GetDlgEdit  (IDC_EDIT5 )->SetReadOnly(1);

	m_cTabCtrl.InsertItem(0,"Kreditberechnung");
	m_cTabCtrl.InsertItem(1,"Sparanlage");

	return TRUE;
}


//*****************************************************************************
//*
//*		OnSysCommand
//*
//*****************************************************************************
void CKreditCalculatorDlg::OnSysCommand(UINT nID, LPARAM lParam)
{
	if ((nID & 0xFFF0) == IDM_ABOUTBOX)
		{
		CDialog dlgAbout(IDD_ABOUTBOX);
		dlgAbout.DoModal();
		}
	else{
		CDialog::OnSysCommand(nID, lParam);
		}
}


//*****************************************************************************
//*
//*		OnPaint
//*
//*****************************************************************************
//  Wollen Sie Ihrem Dialogfeld eine Schaltflche "Minimieren" hinzufgen, bentigen Sie
//  den nachstehenden Code, um das Symbol zu zeichnen. Fr MFC-Anwendungen, die das
//  Dokument/Ansicht-Modell verwenden, wird dies automatisch fr Sie erledigt.
void CKreditCalculatorDlg::OnPaint()
{
	if (IsIconic())
		{
		CPaintDC dc(this); // Gertekontext fr Zeichnen

		SendMessage(WM_ICONERASEBKGND, (WPARAM) dc.GetSafeHdc(), 0);

		// Symbol in Client-Rechteck zentrieren
		int cxIcon = GetSystemMetrics(SM_CXICON);
		int cyIcon = GetSystemMetrics(SM_CYICON);
		CRect rect;
		GetClientRect(&rect);
		int x = (rect.Width () - cxIcon + 1) / 2;
		int y = (rect.Height() - cyIcon + 1) / 2;

		// Symbol zeichnen
		dc.DrawIcon(x, y, m_hIcon);
		}
	else{
		CDialog::OnPaint();
		}
}


//*****************************************************************************
//*
//*		OnQueryDragIcon
//*
//*****************************************************************************
HCURSOR CKreditCalculatorDlg::OnQueryDragIcon()
{
	return (HCURSOR) m_hIcon;
}



//*****************************************************************************
//*
//*		OnCheck?
//*
//*****************************************************************************
void CKreditCalculatorDlg::OnCheck1(){OnCheck(1);}
void CKreditCalculatorDlg::OnCheck2(){OnCheck(2);}
void CKreditCalculatorDlg::OnCheck3(){OnCheck(3);}
void CKreditCalculatorDlg::OnCheck4(){OnCheck(4);}
void CKreditCalculatorDlg::OnCheck6(){OnCheck(6);}
void CKreditCalculatorDlg::OnCheck(int iNr)
{
	iFixNr = iNr;
	UpdateData(FALSE);

	GetDlgButton(IDC_CHECK1)->SetCheck((iFixNr==1)? 1:0);
	GetDlgButton(IDC_CHECK2)->SetCheck((iFixNr==2)? 1:0);
	GetDlgButton(IDC_CHECK3)->SetCheck((iFixNr==3)? 1:0);
	GetDlgButton(IDC_CHECK4)->SetCheck((iFixNr==4)? 1:0);
	GetDlgButton(IDC_CHECK5)->SetCheck((iFixNr==6)? 1:0);
	GetDlgEdit(IDC_EDIT1)->SetReadOnly((iFixNr==1)? 1:0);
	GetDlgEdit(IDC_EDIT2)->SetReadOnly((iFixNr==2)? 1:0);
	GetDlgEdit(IDC_EDIT3)->SetReadOnly((iFixNr==3)? 1:0);
	GetDlgEdit(IDC_EDIT4)->SetReadOnly((iFixNr==4)? 1:0);
	GetDlgEdit(IDC_EDIT5)->SetReadOnly((iFixNr==4)? 1:0);
	GetDlgEdit(IDC_EDIT6)->SetReadOnly((iFixNr==6)? 1:0);

}


//*****************************************************************************
//*
//*		OnChangeEdit?
//*
//*****************************************************************************
void CKreditCalculatorDlg::OnKillfocusEdit1(){OnChangeEdit(1);}
void CKreditCalculatorDlg::OnKillfocusEdit2(){OnChangeEdit(2);}
void CKreditCalculatorDlg::OnKillfocusEdit3(){OnChangeEdit(3);}
void CKreditCalculatorDlg::OnKillfocusEdit4(){OnChangeEdit(4);}
void CKreditCalculatorDlg::OnKillfocusEdit5(){OnChangeEdit(5);}
void CKreditCalculatorDlg::OnKillfocusEdit6(){OnChangeEdit(6);}
void CKreditCalculatorDlg::OnChangeEdit1(){OnChangeEdit(1);}
void CKreditCalculatorDlg::OnChangeEdit2(){OnChangeEdit(2);}
void CKreditCalculatorDlg::OnChangeEdit3(){OnChangeEdit(3);}
void CKreditCalculatorDlg::OnChangeEdit4(){OnChangeEdit(4);}
void CKreditCalculatorDlg::OnChangeEdit5(){OnChangeEdit(5);}
void CKreditCalculatorDlg::OnChangeEdit6(){OnChangeEdit(6);}
void CKreditCalculatorDlg::OnChangeEdit(int iNr)
{

	UpdateData();

	if(iTypNr==0)
		{
		switch(iFixNr)		// dSparziel sind hier die Spesen
			{
		case 1:	dSumme	  = KreditSumme(dRate,dZinsen,dLaufzeit,dSparziel);	break;
		case 2:	dZinsen	  = KreditZinsen(dSumme,dLaufzeit,dRate,dSparziel);	break;
		case 3:	dRate	  = KreditRate(dSumme,dZinsen,dLaufzeit,dSparziel);	break;
		case 4:	dLaufzeit = KreditLaufzeit(dSumme,dZinsen,dRate,dSparziel);	dJahre=dLaufzeit/12.0;	break;
		case 5:	dLaufzeit = KreditLaufzeit(dSumme,dZinsen,dRate,dSparziel);	dJahre=dLaufzeit/12.0;	break;
		case 6:	dSparziel = KreditSpesen  (dSumme,dRate,dZinsen,dLaufzeit);	break;
			}

		dZahlung	 = dLaufzeit*dRate;
		dZinszahlung = dZahlung-dSumme;
		}

	if(iTypNr==1)
		{
		switch(iFixNr)
			{
		case 1:	dSumme	  = SparSumme(dRate,dZinsen,dLaufzeit,dSparziel);	break;
		case 2:	dZinsen	  = SparZinsen(dSumme,dLaufzeit,dRate,dSparziel);	break;
		case 3:	dRate	  = SparRate(dSumme,dZinsen,dLaufzeit,dSparziel);	break;
		case 4:	dLaufzeit = SparLaufzeit(dSumme,dZinsen,dRate,dSparziel);	dJahre=dLaufzeit/12.0;	break;
		case 5:	dLaufzeit = SparLaufzeit(dSumme,dZinsen,dRate,dSparziel);	dJahre=dLaufzeit/12.0;	break;
		case 6:	dSparziel = SparSparziel(dSumme,dZinsen,dRate,dLaufzeit);	break;
			}

		dZahlung = dLaufzeit*dRate+dSumme;
		dZinszahlung = dSparziel-dZahlung;
		}

	UpdateData(FALSE);
}




//*****************************************************************************
//*
//*		OnSelchangeTab
//*
//*****************************************************************************
void CKreditCalculatorDlg::OnSelchangeTab(NMHDR *pNmHdr, LRESULT *pResult)
{

	iTypNr=m_cTabCtrl.GetCurSel();

	SetDlgItemText(IDC_TEXT1,(iTypNr==0)? "Kreditsumme :":"Anfangseinzahlung :");
	SetDlgItemText(IDC_TEXT3,(iTypNr==0)? "Monatsrate :" :"Einzahlung/Monat :" );
	SetDlgItemText(IDC_TEXT6,(iTypNr==0)? "Spesen :"     :"Ansparziel :"       );
	SetDlgItemText(IDC_TEXT7,(iTypNr==0)? "Rckzahlung :":"Einzahlungzahlung :");
	SetDlgItemText(IDC_TEXT8,(iTypNr==0)? "Zinszahlung :":"Zinsertrag :");

	if(iTypNr==0 && iFixNr==6)OnCheck(4);

	*pResult = 0;

	OnChangeEdit(iFixNr);
}



//*****************************************************************************
//*
//*		OnCtlColor
//*
//*****************************************************************************
HBRUSH CKreditCalculatorDlg::OnCtlColor(CDC *pDC,CWnd *pWnd,UINT nCtlColor)
{
HBRUSH		hBrush;
unsigned 	uId;


	hBrush  = CDialog::OnCtlColor(pDC,pWnd,nCtlColor);
	uId		= GetWindowLong(pWnd->m_hWnd,GWL_ID);

	switch(uId)
		{
	case IDC_EDIT1: pDC->SetBkColor((iFixNr==1)? COLOR_DIS:COLOR_DEF);	return (iFixNr==1)? hBrushDis:hBrushDef;
	case IDC_EDIT2: pDC->SetBkColor((iFixNr==2)? COLOR_DIS:COLOR_DEF);	return (iFixNr==2)? hBrushDis:hBrushDef;
	case IDC_EDIT3: pDC->SetBkColor((iFixNr==3)? COLOR_DIS:COLOR_DEF);	return (iFixNr==3)? hBrushDis:hBrushDef;
	case IDC_EDIT4: pDC->SetBkColor((iFixNr==4)? COLOR_DIS:COLOR_DEF);	return (iFixNr==4)? hBrushDis:hBrushDef;
	case IDC_EDIT5: pDC->SetBkColor((iFixNr==4)? COLOR_DIS:COLOR_DEF);	return (iFixNr==4)? hBrushDis:hBrushDef;
	case IDC_EDIT6: pDC->SetBkColor((iFixNr==6)? COLOR_DIS:COLOR_DEF);	return (iFixNr==6)? hBrushDis:hBrushDef;
	case IDC_EDIT7:	pDC->SetBkColor(			 COLOR_OUT          );	return						  hBrushOut;
	case IDC_EDIT8:	pDC->SetBkColor(		 	 COLOR_OUT          );	return						  hBrushOut;
		}



return hBrush;
}
